Learn R Programming

trafficCAR (version 0.1.0)

trafficCAR-package: trafficCAR: Bayesian CAR Models for Road-Segment Traffic

Description

Tools for simulating and modeling traffic flow on road networks using spatial conditional autoregressive (CAR) models. The package represents road systems as graphs derived from 'OpenStreetMap' data https://www.openstreetmap.org/ and supports network-based spatial dependence, basic preprocessing, and visualization for spatial traffic analysis.

Arguments

Author

Maintainer: Madison Ell mell@stat.tamu.edu